@@ -16,8 +16,9 @@ impl Clone for OwnedObject {
     }
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Default)]
 pub enum AnyValue<'a> {
+    #[default]
     Null,
     /// A binary true or false.
     Boolean(bool),
@@ -82,12 +83,6 @@ pub enum AnyValue<'a> {
     BinaryOwned(Vec<u8>),
 }
 
-impl Default for AnyValue<'static> {
-    fn default() -> Self {
-        AnyValue::Null
-    }
-}
-
 #[cfg(feature = "serde")]
 impl Serialize for AnyValue<'_> {
     fn serialize<S>(&self, serializer: S) -> std::result::Result<S::Ok, S::Error>
