@@ -508,7 +508,7 @@ mod test {
                     "2020-01-08 23:16:43",
                 ],
             )
-            .as_datetime(None, tu, false, false)?
+            .as_datetime(None, tu, false, false, false)?
             .into_series();
             let a = Series::new("a", [3, 7, 5, 9, 2, 1]);
             let df = DataFrame::new(vec![date, a.clone()])?;
@@ -546,7 +546,7 @@ mod test {
                 "2020-01-08 23:16:43",
             ],
         )
-        .as_datetime(None, TimeUnit::Milliseconds, false, false)?
+        .as_datetime(None, TimeUnit::Milliseconds, false, false, false)?
         .into_series();
         let a = Series::new("a", [3, 7, 5, 9, 2, 1]);
         let df = DataFrame::new(vec![date, a.clone()])?;
@@ -603,7 +603,7 @@ mod test {
     }
 
     #[test]
-    fn test_dynamic_groupby_window() {
+    fn test_dynamic_groupby_window() -> PolarsResult<()> {
         let start = NaiveDate::from_ymd_opt(2021, 12, 16)
             .unwrap()
             .and_hms_opt(0, 0, 0)
@@ -622,7 +622,7 @@ mod test {
             ClosedWindow::Both,
             TimeUnit::Milliseconds,
             None,
-        )
+        )?
         .into_series();
 
         let groups = Series::new("groups", ["a", "a", "a", "b", "b", "a", "a"]);
@@ -674,7 +674,7 @@ mod test {
             ClosedWindow::Both,
             TimeUnit::Milliseconds,
             None,
-        )
+        )?
         .into_series();
         assert_eq!(&upper, &range);
 
@@ -697,7 +697,7 @@ mod test {
             ClosedWindow::Both,
             TimeUnit::Milliseconds,
             None,
-        )
+        )?
         .into_series();
         assert_eq!(&upper, &range);
 
@@ -713,6 +713,7 @@ mod test {
             .into(),
         );
         assert_eq!(expected, groups);
+        Ok(())
     }
 
     #[test]
@@ -735,7 +736,7 @@ mod test {
     }
 
     #[test]
-    fn test_truncate_offset() {
+    fn test_truncate_offset() -> PolarsResult<()> {
         let start = NaiveDate::from_ymd_opt(2021, 3, 1)
             .unwrap()
             .and_hms_opt(12, 0, 0)
@@ -754,7 +755,7 @@ mod test {
             ClosedWindow::Both,
             TimeUnit::Milliseconds,
             None,
-        )
+        )?
         .into_series();
 
         let groups = Series::new("groups", ["a", "a", "a", "b", "b", "a", "a"]);
@@ -779,5 +780,6 @@ mod test {
         time_key.rename("");
         lower_bound.rename("");
         assert!(time_key.series_equal(&lower_bound));
+        Ok(())
     }
 }
