@@ -28,7 +28,6 @@ from polars.utils import (
     _datetime_to_pl_timestamp,
     _time_to_pl_time,
     _timedelta_to_pl_timedelta,
-    deprecated_alias,
 )
 
 try:
@@ -194,7 +193,7 @@ def col(
 
     """
     if isinstance(name, pli.Series):
-        name = name.to_list()  # type: ignore[assignment]
+        name = name.to_list()
 
     if isinstance(name, DataTypeClass):
         name = [name]
@@ -231,7 +230,7 @@ def element() -> pli.Expr:
     A horizontal rank computation by taking the elements of a list
 
     >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2]})
-    >>> df.with_column(
+    >>> df.with_columns(
     ...     pl.concat_list(["a", "b"]).arr.eval(pl.element().rank()).alias("rank")
     ... )
     shape: (3, 3)
@@ -248,7 +247,7 @@ def element() -> pli.Expr:
     A mathematical operation on array elements
 
     >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2]})
-    >>> df.with_column(
+    >>> df.with_columns(
     ...     pl.concat_list(["a", "b"]).arr.eval(pl.element() * 2).alias("a_b_doubled")
     ... )
     shape: (3, 3)
@@ -645,7 +644,7 @@ def sum(
 
     Sum a list of columns/expressions horizontally:
 
-    >>> df.with_column(pl.sum(["a", "c"]))
+    >>> df.with_columns(pl.sum(["a", "c"]))
     shape: (2, 4)
     ┌─────┬─────┬─────┬─────┐
     │ a   ┆ b   ┆ c   ┆ sum │
@@ -1082,7 +1081,7 @@ def tail(column: str | pli.Series, n: int = 10) -> pli.Expr | pli.Series:
 
 
 def lit(
-    value: Any, dtype: type[DataType] | None = None, allow_object: bool = False
+    value: Any, dtype: PolarsDataType | None = None, allow_object: bool = False
 ) -> pli.Expr:
     """
     Return an expression representing a literal value.
@@ -1247,7 +1246,7 @@ def cumsum(
 
     Cumulatively sum a list of columns/expressions horizontally:
 
-    >>> df.with_column(pl.cumsum(["a", "c"]))
+    >>> df.with_columns(pl.cumsum(["a", "c"]))
     shape: (2, 4)
     ┌─────┬─────┬─────┬───────────┐
     │ a   ┆ b   ┆ c   ┆ cumsum    │
@@ -1383,7 +1382,7 @@ def cov(
 def map(
     exprs: Sequence[str] | Sequence[pli.Expr],
     f: Callable[[Sequence[pli.Series]], pli.Series],
-    return_dtype: type[DataType] | None = None,
+    return_dtype: PolarsDataType | None = None,
 ) -> pli.Expr:
     """
     Map a custom function over multiple columns/expressions.
@@ -1413,7 +1412,7 @@ def map(
 def apply(
     exprs: Sequence[str | pli.Expr],
     f: Callable[[Sequence[pli.Series]], pli.Series | Any],
-    return_dtype: type[DataType] | None = None,
+    return_dtype: PolarsDataType | None = None,
     returns_scalar: bool = True,
 ) -> pli.Expr:
     """
@@ -1591,11 +1590,11 @@ def any(name: str | Sequence[str] | Sequence[pli.Expr] | pli.Expr) -> pli.Expr:
 def exclude(
     columns: (
         str
+        | PolarsDataType
         | Sequence[str]
-        | DataType
-        | type[DataType]
-        | DataType
-        | Sequence[DataType | type[DataType]]
+        | Sequence[PolarsDataType]
+        | set[PolarsDataType]
+        | frozenset[PolarsDataType]
     ),
 ) -> pli.Expr:
     """
@@ -2176,14 +2175,12 @@ def concat_list(exprs: Sequence[str | pli.Expr | pli.Series] | pli.Expr) -> pli.
     return pli.wrap_expr(_concat_lst(exprs))
 
 
-@deprecated_alias(allow_streaming="streaming")
 def collect_all(
     lazy_frames: Sequence[pli.LazyFrame],
     type_coercion: bool = True,
     predicate_pushdown: bool = True,
     projection_pushdown: bool = True,
     simplify_expression: bool = True,
-    string_cache: bool = False,
     no_optimization: bool = False,
     slice_pushdown: bool = True,
     common_subplan_elimination: bool = True,
@@ -2206,8 +2203,6 @@ def collect_all(
         Do projection pushdown optimization.
     simplify_expression
         Run simplify expressions optimization.
-    string_cache
-        This argument is deprecated and will be ignored
     no_optimization
         Turn off optimizations.
     slice_pushdown
@@ -2252,6 +2247,7 @@ def collect_all(
 
 def select(
     exprs: str | pli.Expr | Sequence[str | pli.Expr] | pli.Series,
+    **named_exprs: Any,
 ) -> pli.DataFrame:
     """
     Run polars expressions without a context.
@@ -2262,6 +2258,8 @@ def select(
     ----------
     exprs
         Expressions to run
+    **named_exprs
+        Named expressions, provided as kwargs.
 
     Returns
     -------
@@ -2288,7 +2286,7 @@ def select(
     └─────┘
 
     """
-    return pli.DataFrame([]).select(exprs)
+    return pli.DataFrame([]).select(exprs, **named_exprs)
 
 
 @overload
@@ -2360,7 +2358,7 @@ def struct(
     >>> df = pl.DataFrame(
     ...     {"a": [1, 2, 3, 4], "b": ["one", "two", "three", "four"], "c": [9, 8, 7, 6]}
     ... )
-    >>> df.with_column(pl.struct(pl.col(["a", "b"])).alias("a_and_b"))
+    >>> df.with_columns(pl.struct(pl.col(["a", "b"])).alias("a_and_b"))
     shape: (4, 4)
     ┌─────┬───────┬─────┬─────────────┐
     │ a   ┆ b     ┆ c   ┆ a_and_b     │
@@ -2543,9 +2541,9 @@ def coalesce(
     ...         (None, None, 3.0),
     ...         (None, None, None),
     ...     ],
-    ...     columns=[("a", pl.Float64), ("b", pl.Float64), ("c", pl.Float64)],
+    ...     schema=[("a", pl.Float64), ("b", pl.Float64), ("c", pl.Float64)],
     ... )
-    >>> df.with_column(pl.coalesce(["a", "b", "c", 99.9]).alias("d"))
+    >>> df.with_columns(pl.coalesce(["a", "b", "c", 99.9]).alias("d"))
     shape: (4, 4)
     ┌──────┬──────┬──────┬──────┐
     │ a    ┆ b    ┆ c    ┆ d    │
