@@ -20,7 +20,6 @@ else:
 import polars as pl
 from polars.datatypes import DATETIME_DTYPES, DTYPE_TEMPORAL_UNITS, PolarsTemporalType
 from polars.testing import assert_frame_equal, assert_series_equal
-from polars.testing._private import verify_series_and_expr_api
 
 if TYPE_CHECKING:
     from polars.internals.type_aliases import TimeUnit
@@ -712,7 +711,7 @@ def test_truncate_negative_offset() -> None:
 
         out = df.groupby_dynamic(
             "idx", every="2i", period="3i", include_boundaries=True
-        ).agg(pl.col("A").list())
+        ).agg(pl.col("A"))
 
         assert out.shape == (3, 4)
         assert out["A"].to_list() == [["A", "A", "B"], ["B", "B", "B"], ["B", "C"]]
@@ -727,24 +726,22 @@ def test_to_arrow() -> None:
 
 
 def test_non_exact_strptime() -> None:
-    a = pl.Series("a", ["2022-01-16", "2022-01-17", "foo2022-01-18", "b2022-01-19ar"])
+    s = pl.Series("a", ["2022-01-16", "2022-01-17", "foo2022-01-18", "b2022-01-19ar"])
     fmt = "%Y-%m-%d"
 
+    result = s.str.strptime(pl.Date, fmt, strict=False, exact=True)
     expected = pl.Series("a", [date(2022, 1, 16), date(2022, 1, 17), None, None])
-    verify_series_and_expr_api(
-        a, expected, "str.strptime", pl.Date, fmt, strict=False, exact=True
-    )
+    assert_series_equal(result, expected)
 
+    result = s.str.strptime(pl.Date, fmt, strict=False, exact=False)
     expected = pl.Series(
         "a",
         [date(2022, 1, 16), date(2022, 1, 17), date(2022, 1, 18), date(2022, 1, 19)],
     )
-    verify_series_and_expr_api(
-        a, expected, "str.strptime", pl.Date, fmt, strict=False, exact=False
-    )
+    assert_series_equal(result, expected)
 
     with pytest.raises(Exception):
-        a.str.strptime(pl.Date, fmt, strict=True, exact=True)
+        s.str.strptime(pl.Date, fmt, strict=True, exact=True)
 
 
 def test_explode_date() -> None:
@@ -1161,7 +1158,7 @@ def test_rolling_groupby_by_argument() -> None:
     df = pl.DataFrame({"times": range(10), "groups": [1] * 4 + [2] * 6})
 
     out = df.groupby_rolling("times", period="5i", by=["groups"]).agg(
-        pl.col("times").list().alias("agg_list")
+        pl.col("times").alias("agg_list")
     )
 
     expected = pl.DataFrame(
@@ -1549,7 +1546,7 @@ def test_duration_aggregations() -> None:
             pl.col("duration").max().alias("max"),
             pl.col("duration").quantile(0.1).alias("quantile"),
             pl.col("duration").median().alias("median"),
-            pl.col("duration").list().alias("list"),
+            pl.col("duration").alias("list"),
         ]
     ).to_dict(False) == {
         "group": ["A", "B"],
@@ -2051,6 +2048,19 @@ def test_with_time_zone_none() -> None:
     assert result.item() == datetime(2001, 1, 1, 0, 0)
 
 
+def test_with_time_zone_invalid() -> None:
+    ts = pl.Series(["2020-01-01"]).str.strptime(pl.Datetime)
+    with pytest.raises(ComputeError, match="Could not parse timezone: 'foo'"):
+        ts.dt.with_time_zone("foo")
+
+
+def test_with_time_zone_fixed_offset() -> None:
+    ts = pl.Series(["2020-01-01"]).str.strptime(pl.Datetime)
+    result = ts.dt.with_time_zone("+00:00")
+    assert result.dtype == pl.Datetime("us", "+00:00")
+    assert result.item() == datetime(2020, 1, 1, 0, 0, tzinfo=timezone.utc)
+
+
 def test_tz_aware_get_idx_5010() -> None:
     when = int(
         datetime(2022, 1, 1, 12, tzinfo=zoneinfo.ZoneInfo("Asia/Shanghai")).timestamp()
@@ -2168,6 +2178,28 @@ def test_tz_localize() -> None:
     }
 
 
+@pytest.mark.parametrize("time_zone", ["UTC", "Africa/Abidjan"])
+def test_tz_localize_from_utc(time_zone: str) -> None:
+    ts_utc = (
+        pl.Series(["2018-10-28"]).str.strptime(pl.Datetime).dt.tz_localize(time_zone)
+    )
+    with pytest.raises(
+        ComputeError,
+        match=(
+            "^Cannot localize a tz-aware datetime. Consider using "
+            "'dt.with_time_zone' or 'dt.cast_time_zone'$"
+        ),
+    ):
+        ts_utc.dt.tz_localize("America/Maceio")
+
+
+def test_unlocalize() -> None:
+    tz_naive = pl.Series(["2020-01-01 03:00:00"]).str.strptime(pl.Datetime)
+    tz_aware = tz_naive.dt.with_time_zone("Europe/Brussels")
+    result = tz_aware.dt.cast_time_zone(None).item()
+    assert result == datetime(2020, 1, 1, 4)
+
+
 def test_tz_aware_truncate() -> None:
     test = pl.DataFrame(
         {
@@ -2645,3 +2677,40 @@ def test_infer_iso8601(iso8601_format: str) -> None:
         assert parsed.dt.nanosecond().item() == 123456000
     if "%3f" in iso8601_format:
         assert parsed.dt.nanosecond().item() == 123000000
+
+
+@pytest.mark.parametrize("fmt", ["%+", "%Y-%m-%dT%H:%M:%S%z"])
+def test_crossing_dst(fmt: str) -> None:
+    ts = ["2021-03-27T23:59:59+01:00", "2021-03-28T23:59:59+02:00"]
+    result = pl.Series(ts).str.strptime(pl.Datetime, fmt, utc=True)
+    assert result[0] == datetime(
+        2021, 3, 27, 22, 59, 59, tzinfo=zoneinfo.ZoneInfo(key="UTC")
+    )
+    assert result[1] == datetime(
+        2021, 3, 28, 21, 59, 59, tzinfo=zoneinfo.ZoneInfo(key="UTC")
+    )
+
+
+@pytest.mark.parametrize("fmt", ["%+", "%Y-%m-%dT%H:%M:%S%z"])
+def test_crossing_dst_tz_aware(fmt: str) -> None:
+    ts = ["2021-03-27T23:59:59+01:00", "2021-03-28T23:59:59+02:00"]
+    with pytest.raises(
+        ComputeError,
+        match=(
+            r"^Different timezones found during 'strptime' operation. "
+            "You might want to use `utc=True` and then set the time zone after parsing$"
+        ),
+    ):
+        pl.Series(ts).str.strptime(pl.Datetime, fmt, utc=False)
+
+
+def test_utc_with_tz_naive() -> None:
+    ts = ["2021-03-27T23:59:59", "2021-03-28T23:59:59"]
+    with pytest.raises(
+        ComputeError,
+        match=(
+            r"Cannot use 'utc=True' with tz-naive data. "
+            r"Parse the data as naive, and then use `.dt.with_time_zone\('UTC'\)"
+        ),
+    ):
+        pl.Series(ts).str.strptime(pl.Datetime, "%Y-%m-%dT%H:%M:%S", utc=True)
