@@ -63,9 +63,10 @@ def test_special_char_colname_init() -> None:
         assert len(df.rows()) == 0
         assert df.is_empty()
 
-        # remove once 'columns' -> 'schema' transition complete
-        df2 = pl.DataFrame(columns=cols)  # type: ignore[call-arg]
-        assert_frame_equal(df, df2)
+        # TODO: remove once 'columns' -> 'schema' transition complete
+        with pytest.deprecated_call():
+            df2 = pl.DataFrame(columns=cols)  # type: ignore[call-arg]
+            assert_frame_equal(df, df2)
 
 
 def test_comparisons() -> None:
@@ -1083,9 +1084,9 @@ def test_string_cache_eager_lazy() -> None:
         # also check row-wise categorical insert.
         # (column-wise is preferred, but this shouldn't fail)
         for params in (
-            {"columns": [("region_ids", pl.Categorical)]},
+            {"schema": [("region_ids", pl.Categorical)]},
             {
-                "columns": ["region_ids"],
+                "schema": ["region_ids"],
                 "schema_overrides": {"region_ids": pl.Categorical},
             },
         ):
@@ -1264,6 +1265,14 @@ def test_from_generator_or_iterable() -> None:
         assert expected_data == d.row_tuples()
         assert expected_schema == list(zip(d.columns(), d.dtypes()))
 
+    # ref: issue #6489 (initial chunk_size cannot be smaller than 'infer_schema_length')
+    df = pl.DataFrame(
+        data=iter(([{"col": None}] * 1000) + [{"col": ["a", "b", "c"]}]),
+        infer_schema_length=1001,
+    )
+    assert df.schema == {"col": pl.List(pl.Utf8)}
+    assert df[-2:]["col"].to_list() == [None, ["a", "b", "c"]]
+
     # empty iterator
     assert_frame_equal(
         pl.DataFrame(data=gen(0), schema=["a", "b", "c", "d"]),
@@ -1613,6 +1622,10 @@ def test_select_by_dtype(df: pl.DataFrame) -> None:
     assert out.columns == ["strings", "strings_nulls", "bools", "bools_nulls"]
     out = df.select(pl.col(INTEGER_DTYPES))
     assert out.columns == ["int", "int_nulls"]
+    out = df.select(ints=pl.col(INTEGER_DTYPES))
+    assert out.schema == {
+        "ints": pl.Struct([pl.Field("int", pl.Int64), pl.Field("int_nulls", pl.Int64)])
+    }
 
 
 def test_with_row_count() -> None:
@@ -1712,7 +1725,7 @@ def test_extension() -> None:
     df = pl.DataFrame({"groups": [1, 1, 2], "a": foos})
     assert sys.getrefcount(foos[0]) == base_count + 1
 
-    out = df.groupby("groups", maintain_order=True).agg(pl.col("a").list().alias("a"))
+    out = df.groupby("groups", maintain_order=True).agg(pl.col("a").alias("a"))
     assert sys.getrefcount(foos[0]) == base_count + 2
     s = out["a"].arr.explode()
     assert sys.getrefcount(foos[0]) == base_count + 3
@@ -2214,13 +2227,6 @@ def test_preservation_of_subclasses_after_groupby_statements() -> None:
     groupby = subclassed_df.groupby("a")
     assert isinstance(groupby.agg(pl.count()), SubClassedDataFrame)
 
-    # Round-trips to PivotOps and back should also preserve subclass
-    with pytest.deprecated_call():
-        assert isinstance(
-            groupby.pivot(pivot_column="a", values_column="b").first(),
-            SubClassedDataFrame,
-        )
-
 
 def test_explode_empty() -> None:
     df = (
@@ -2410,6 +2416,33 @@ def test_selection_regex_and_multicol() -> None:
         "c": [81, 100, 121, 144],
     }
 
+    # kwargs
+    df = test_df.select(
+        re=pl.col("^\\w$"),
+        odd=(pl.col(INTEGER_DTYPES) % 2).suffix("_is_odd"),
+        maxes=pl.all().max().suffix("_max"),
+    ).head(2)
+    # ┌───────────┬───────────┬─────────────┐
+    # │ re        ┆ odd       ┆ maxes       │
+    # │ ---       ┆ ---       ┆ ---         │
+    # │ struct[3] ┆ struct[4] ┆ struct[4]   │
+    # ╞═══════════╪═══════════╪═════════════╡
+    # │ {1,5,9}   ┆ {1,1,1,1} ┆ {4,8,12,16} │
+    # │ {2,6,10}  ┆ {0,0,0,0} ┆ {4,8,12,16} │
+    # └───────────┴───────────┴─────────────┘
+    assert df.rows() == [
+        (
+            {"a": 1, "b": 5, "c": 9},
+            {"a_is_odd": 1, "b_is_odd": 1, "c_is_odd": 1, "foo_is_odd": 1},
+            {"a_max": 4, "b_max": 8, "c_max": 12, "foo_max": 16},
+        ),
+        (
+            {"a": 2, "b": 6, "c": 10},
+            {"a_is_odd": 0, "b_is_odd": 0, "c_is_odd": 0, "foo_is_odd": 0},
+            {"a_max": 4, "b_max": 8, "c_max": 12, "foo_max": 16},
+        ),
+    ]
+
 
 def test_with_columns() -> None:
     import datetime
@@ -2487,9 +2520,52 @@ def test_with_columns() -> None:
     )
     assert_frame_equal(dx, expected)
 
-    # at least one of exprs/**named_exprs required
+    # automatically upconvert multi-output expressions to struct
+    ldf = (
+        pl.DataFrame({"x1": [1, 2, 6], "x2": [1, 2, 3]})
+        .lazy()
+        .with_columns(
+            pct_change=pl.col(["x1", "x2"]).pct_change(),
+            maxes=pl.all().max().suffix("_max"),
+            xcols=pl.col("^x.*$"),
+        )
+    )
+    # ┌─────┬─────┬─────────────┬───────────┬───────────┐
+    # │ x1  ┆ x2  ┆ pct_change  ┆ maxes     ┆ xcols     │
+    # │ --- ┆ --- ┆ ---         ┆ ---       ┆ ---       │
+    # │ i64 ┆ i64 ┆ struct[2]   ┆ struct[2] ┆ struct[2] │
+    # ╞═════╪═════╪═════════════╪═══════════╪═══════════╡
+    # │ 1   ┆ 1   ┆ {null,null} ┆ {6,3}     ┆ {1,1}     │
+    # │ 2   ┆ 2   ┆ {1.0,1.0}   ┆ {6,3}     ┆ {2,2}     │
+    # │ 6   ┆ 3   ┆ {2.0,0.5}   ┆ {6,3}     ┆ {6,3}     │
+    # └─────┴─────┴─────────────┴───────────┴───────────┘
+    assert ldf.collect().to_dicts() == [
+        {
+            "x1": 1,
+            "x2": 1,
+            "pct_change": {"x1": None, "x2": None},
+            "maxes": {"x1_max": 6, "x2_max": 3},
+            "xcols": {"x1": 1, "x2": 1},
+        },
+        {
+            "x1": 2,
+            "x2": 2,
+            "pct_change": {"x1": 1.0, "x2": 1.0},
+            "maxes": {"x1_max": 6, "x2_max": 3},
+            "xcols": {"x1": 2, "x2": 2},
+        },
+        {
+            "x1": 6,
+            "x2": 3,
+            "pct_change": {"x1": 2.0, "x2": 0.5},
+            "maxes": {"x1_max": 6, "x2_max": 3},
+            "xcols": {"x1": 6, "x2": 3},
+        },
+    ]
+
+    # require at least one of exprs / **named_exprs
     with pytest.raises(ValueError):
-        _ = df.with_columns()
+        _ = ldf.with_columns()
 
 
 def test_len_compute(df: pl.DataFrame) -> None:
@@ -2613,7 +2689,7 @@ def test_init_datetimes_with_timezone() -> None:
     for tu in DTYPE_TEMPORAL_UNITS | frozenset([None]):
         for type_overrides in (
             {
-                "columns": [
+                "schema": [
                     ("d1", pl.Datetime(tu, tz_us)),
                     ("d2", pl.Datetime(tu, tz_europe)),
                 ]
